package gui;

import java.awt.Image;
import java.util.HashMap;
import java.util.Map;

/**
 * In this class the images for the imagePanelToolbarDecorator can be registered.
 * It is a Singleton.
 */
public class ImageRegistry {

	private static ImageRegistry instance;
	
	Map<String,Image> images;
	
	/**
	 * Private constructor
	 */
	private ImageRegistry() {
		images=new HashMap<String,Image>();
	}
	
	/**
	 * Returns the instance and creates one if it was null before
	 * @return instance
	 */
	public static ImageRegistry getInstance(){
		if(instance==null){
			instance=new ImageRegistry();
		}
		return instance;
	}
	
	/**
	 * Add an icon to the Map of images
	 * @param name
	 * @param i
	 */
	public void addImage(String name,Image i){
		images.put(name, i);
	}
	
	/**
	 * Get an image from the Map
	 * @param name
	 * @return Image
	 */
	public Image getImage(String name){
		return images.get(name);
	}

}
