package gui.hough;

import houghtransform.HoughCircles;
import houghtransform.HoughLines;
import ij.ImagePlus;

import java.awt.Point;
import java.util.Iterator;
import java.util.List;

import appLogic.Simulatable;
import appLogic.Simulation;

/**
 * The houghSpaceAnimation contains the hough animation panel and it is
 * responsible for the simulation of the hough lines.
 */
public class HoughSpaceAnimation extends ImagePanel implements Simulatable {

	private static final long serialVersionUID = -1285386000523678691L;

	private ImagePlus imageSpace;
	private int state=1;

	// private Simulation simulation;

	private HoughCircles houghcircles;
	private HoughLines houghlines;
	
	private List<Point> nonBlackPixels;

	private Iterator<Point> nonBlackPixelsIt;
	private int radmin;
	/**
	 * Standard constructor
	 * 
	 * @param imp
	 */
	public HoughSpaceAnimation(ImagePlus imp,int state,int radmin) {
		super(new HoughLines(imp, 256, 256).getHoughSpaceImage(), 3);
		imageSpace = imp;
		this.state=state;
		this.radmin=radmin;
		if (state==1)	{
			houghlines = new HoughLines(imp, 256, 256);
			nonBlackPixels =  houghlines.getNonBlackPixels();
		}
		else{
			houghcircles = new HoughCircles(imp,radmin);
			nonBlackPixels =  houghcircles.getNonBlackPixels();
		}
		

		nonBlackPixelsIt = nonBlackPixels.iterator();
	}

	/**
	 * Go to the next white pixel if there exists one
	 */
	public void update() {
		if (nonBlackPixelsIt.hasNext()) {
			Point p = nonBlackPixelsIt.next();
			
			if(state==1){
				houghlines.accumulateHoughCurve(p.x, p.y);
				image =  houghlines.getHoughSpaceImage();
			}
			else {
				houghcircles.accumulateHoughCircle(p.x, p.y,radmin,radmin);
				image =  houghcircles.getHoughSpaceImage(0);
			}
			
			fireImageChanged();

		}

	}

	/**
	 * @see appLogic.Simulation
	 */
	public void init(Simulation s) {
		// simulation=s;
	}

	/**
	 * @see appLogic.Simulation
	 */
	public void pause() {
	}

	/**
	 * Resets the canvas for the hough lines
	 */
	public void reset() {
		if(state==1){
			HoughLines hough = new HoughLines(imageSpace, 256, 256);
			image = hough.getHoughSpaceImage();
		}
		else{
			HoughCircles hough = new HoughCircles(imageSpace,1);
			image = hough.getHoughSpaceImage(0);
		}
		
		fireImageChanged();
		nonBlackPixelsIt = nonBlackPixels.iterator();
	}

	/**
	 * @see appLogic.Simulation
	 */
	public void resume() {
	}

	/**
	 * @see appLogic.Simulation
	 */
	public void start() {
	}

}
