package gui.hough;

import houghtransform.HoughCircles;
import houghtransform.HoughLines;
import ij.ImagePlus;
import ij.process.FloatProcessor;
import ij.process.ImageProcessor;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Point;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;
import java.util.HashMap;
import java.util.List;

/**
 * This class is an ImagePanel that represents the maxima section for the hough space
 */
public class HoughSpaceMaxima extends ImagePanel implements MouseMotionListener {


	private static final long serialVersionUID = -7746956314427207931L;
		
	private HoughLines houghlines;
	private HoughCircles houghcircles;
	private ImagePlus houghLineImage;
	private ImagePlus houghCircleImage;
	private int state;
	private int radmin;
	private int radmax;
	private int shownradius;
	private HashMap<Integer,List <Point>> maxima;

	/**
	 * Standard constructor
	 * @param imp	- an ImagePlus
	 */
	public HoughSpaceMaxima(ImagePlus imp,int state,int radmin, int radmax, int shownradius) {
		super(imp, 3);
		this.state=state;
		this.radmin=radmin;
		this.radmax=radmax;
		this.shownradius=shownradius;
		imp.updateImage();
		if (state==1){
			houghlines=new HoughLines(imp,256,256);
			houghlines.fillHoughSpace();
			List<Point> maxima = houghlines.getMaximaByRelativeIntensity(0.5);
			this.image=houghlines.getMaximaImage(maxima);
		}
		else{
			houghcircles=new HoughCircles(imp,radmax-radmin);
			HashMap<Integer,List <Point>> maxima=new HashMap<Integer,List <Point>>();
			for(int radius=radmin;radius<=radmax;radius++){	
				houghcircles.fillHoughSpace(radius,radmin);		
			}	
			maxima= houghcircles.getMaximaByRelativeIntensity(191/255.0,radmin,radmax); 
			this.image=houghcircles.getMaximaImage(maxima,radmin,shownradius);
			this.maxima=maxima;
		}
		fireImageChanged();	
		
	}
	
	/**
	 * updates the pisture if the threshold has changed
	 * @param threshold
	 * @param nonMaximumSupression	
	 */
	public void updateThreshold(double threshold,boolean nonMaximumSupression, int shownradius){
		if(state==1){
			List<Point> maxima = houghlines.getMaximaByRelativeIntensity(threshold);
			if(nonMaximumSupression) maxima=houghlines.nonMaximumSupression(maxima, houghlines.getMaximaImage(maxima), 0.01);
			image=houghlines.getMaximaImage(maxima);
		}
		else{
			this.shownradius=shownradius;
			HashMap<Integer,List <Point>> maxima=new HashMap<Integer,List <Point>>();
			maxima=houghcircles.getMaximaByRelativeIntensity(threshold,radmin,radmax);		
			image=houghcircles.getMaximaImage(maxima,radmin,shownradius);
			this.maxima=maxima;
		}
		fireImageChanged();	
	}

	@Override
	public void mouseDragged(MouseEvent e) { }

	@Override
	public void mouseMoved(MouseEvent e) {
		if (e.getSource() == this)
			return;
		if (e.getSource() instanceof ImageSpaceWithLines ||e.getSource() instanceof ImageSpaceWithCircles) {
			ImagePanel c = (ImagePanel) e.getSource();

			Point m = new Point(e.getX(), e.getY());
			if (!c.liesOnImage(m))
				return;
			Point p = c.screenToImage(m);
			if (state==1){
				HoughLines hl = new HoughLines(this.image, 256, 256);
				hl.accumulateHoughCurve(p.x, p.y);
				this.houghLineImage = hl.getHoughSpaceImage();
			}
			else{
				HoughCircles hl = new HoughCircles(this.image,1);
				hl.accumulateHoughCircle(p.x, p.y,shownradius,shownradius);
				this.houghCircleImage = hl.getHoughSpaceImage(0);
			}
			this.fireImageChanged();
		}
	}
	
	@Override
	public void paintComponent(Graphics g) {
		ImageProcessor overlayedImage = this.image.getProcessor().duplicate().convertToRGB();
		overlayedImage.setColor(Color.red);
		if (this.houghLineImage != null) {
			FloatProcessor fp = (FloatProcessor) this.houghLineImage.getProcessor();
			for (int x = 0; x < fp.getWidth(); x++)
				for (int y = 0; y < fp.getHeight(); y++)
					if (fp.getPixelValue(x, y) != 0)
						overlayedImage.drawPixel(x, y);
		}
		if (this.houghCircleImage != null) {
			FloatProcessor fp = (FloatProcessor) this.houghCircleImage.getProcessor();
			for (int x = 0; x < fp.getWidth(); x++)
				for (int y = 0; y < fp.getHeight(); y++)
					if (fp.getPixelValue(x, y) != 0)
						overlayedImage.drawPixel(x, y);
		}
		super.paintComponent(g);
		Graphics2D g2d=(Graphics2D)g;
		g2d.drawImage(overlayedImage.getBufferedImage(), this.affineTranform, null);
	}
	public HashMap<Integer,List <Point>>getMaxima(){
		
		return maxima;
		
	}
}
