package gui.hough;

import ij.ImagePlus;

import java.awt.Point;
import java.util.ArrayList;

/**
 * This class represents the maxima section for the image space
 */
public class ImageSpaceMaximaCircles extends ImageSpaceWithCircles {

	private static final long serialVersionUID = -1394247602987868143L;

	private double lastThreshold;


	private int radmin;
	private int radmax;
	private int shownradius;
	/**
	 * Standard constructor
	 * @param imp
	 */
	public ImageSpaceMaximaCircles(ImagePlus imp,int radmin,int radmax,int shownradius) {
		super(imp,radmin,radmax,shownradius);
		this.radmin=radmin;
		this.radmax=radmax;
		this.shownradius=shownradius;
		imp.updateImage();
		lastThreshold=191/255.0;
		this.houghPoints= this.houghCircles.getMaximaByRelativeIntensity(lastThreshold,radmin,radmax);
		this.fireImageChanged();	
	}
	
	/**
	 * Updates the threshold and the image with the hough circles
	 * @param threshold
	 * @param nonMaximumSupression
	 * @param highlightMaxima
	 */
	public void updateThreshold(double threshold, Point highlightMaxima,int shownradius){
		this.shownradius=shownradius;
		lastThreshold=threshold;
		this.drawHoughCircles(highlightMaxima);
	}
	
	public void drawHoughCircles(Point highlightHoughPoint) {
		
		double threshold = this.lastThreshold;
		
		this.houghPoints.clear();
		this.houghPoints=this.houghCircles.getMaximaByRelativeIntensity(threshold,radmin,radmax);
		
		
			if (highlightHoughPoint != null){
			ArrayList<Point> al=new ArrayList<Point>();
			al=(ArrayList<Point>) this.houghPoints.get(shownradius);
			al.add(highlightHoughPoint);
			this.houghPoints.put(shownradius,al);
		}
		this.fireImageChanged();
	}

}
