package gui.sections.info;

import gui.DocBrowser;
import gui.GuiManager;
import gui.InteractionSectionListener;
import gui.sections.Section;

import java.awt.BorderLayout;
import java.util.ArrayList;


/**
 * The InfoSection contains the informational text shown in the lower half of
 * the applet. Every topic has its own informational text, which is written in
 * HTML.
 * 
 */
public class InfoSection extends Section {

	private static final long serialVersionUID = -5338957471296683298L;

	private DocBrowser docBrowser;

	private ArrayList<String> docList;

	/**
	 * The InfoSection constructor adds all info-HTML files from the working
	 * path to the ArrayList doclist and calls that one that belongs to the
	 * actual topic.
	 * 
	 * @param guiManager
	 */
	public InfoSection(final GuiManager guiManager) {
		super(guiManager);
		
		setLayout(new BorderLayout());
		docBrowser = new DocBrowser(getGuiManager().getWorkingPath()+"doku/");
		add(docBrowser);

		
		
		docList = new ArrayList<String>();
		docList.add(getGuiManager().getWorkingPath()+"doku/Hough_InfoLinie.html");
		docList.add(getGuiManager().getWorkingPath()+"doku/Hough_Laden.html");
		docList.add(getGuiManager().getWorkingPath()+"doku/Hough_Vorverarbeitung.html");
		docList.add(getGuiManager().getWorkingPath()+"doku/Hough_BearbeitungLinie.html");
		docList.add(getGuiManager().getWorkingPath()+"doku/Hough_TransformationLinie.html");
		docList.add(getGuiManager().getWorkingPath()+"doku/Hough_Linien.html");

		docList.add(getGuiManager().getWorkingPath()+"doku/Hough_InfoKreis.html");
		docList.add(getGuiManager().getWorkingPath()+"doku/Hough_Laden.html");
		docList.add(getGuiManager().getWorkingPath()+"doku/Hough_Vorverarbeitung.html");
		docList.add(getGuiManager().getWorkingPath()+"doku/Hough_BearbeitungKreis.html");
		docList.add(getGuiManager().getWorkingPath()+"doku/Hough_TransformationKreis.html");
		docList.add(getGuiManager().getWorkingPath()+"doku/Hough_Kreise.html");


		guiManager.getInteractionSectionSwitch().addInteractionSectionListener(
				new InteractionSectionListener() {

					@Override
					public void sectionSwitched(int from, int to) {
						if (to == 0) {
							setVisible(false);
						} else {
							setVisible(true);
							if(guiManager.getState()==1)docBrowser.setEditorUrl( docList.get(to) );
							else docBrowser.setEditorUrl( docList.get(to+6) );

						}
						if (getParent() != null) {
							invalidate();
							getParent().validate();
						}

					}

				});
	}
	
	/**
	 * returns the HTML from a URL
	 * @param url
	 * @return String
	 */
	
	/**
	 * Returns the documentList
	 * @return docList
	 */
	public ArrayList<String> getDocumentList() {
		return docList;
	}
	
	

}
