package gui.sections.interaction;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.NumberFormat;

import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JFormattedTextField;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.text.NumberFormatter;

import gui.DocBrowser;
import gui.GuiManager;
import gui.InteractionSectionListener;
import gui.sections.topic.TopicSection;

/**
 * The DocumentationSection contains the descriptional text of the first topic (Information)
 *
 */
public class DocumentationSection extends InteractionSection{

	private static DocBrowser docBrowser;

	/**
	 * The constructor for the DocumentationSection
	 * @param guiManager
	 */
	public DocumentationSection(final GuiManager guiManager) {
		super(guiManager);
		
		setLayout(new BorderLayout());
		//if(docBrowser==null){
			if (guiManager.getState()==1)docBrowser = new DocBrowser(guiManager.getWorkingPath()+"doku/Hough_InfoLinie.html");
			else docBrowser = new DocBrowser(guiManager.getWorkingPath()+"doku/Hough_InfoKreis.html");
		//}
			
		ButtonGroup group = new ButtonGroup();
		JRadioButton line=new JRadioButton("Geradenerkennung");
		
		line.addActionListener(new ActionListener(){

			@Override
			public void actionPerformed(ActionEvent e) {		
				guiManager.setState(1);	
				((TopicSection)getGuiManager().getsTopic()).changeText(1);
				getGuiManager().switchToInteractionSection(0);
			}	
		});
		JRadioButton circle=new JRadioButton("Kreiserkennung");
		circle.addActionListener(new ActionListener(){

			@Override
			public void actionPerformed(ActionEvent e) {		
				guiManager.setState(2);	
				((TopicSection)getGuiManager().getsTopic()).changeText(2);
				getGuiManager().switchToInteractionSection(0);
			}	
		});
		if (guiManager.getState()==1)line.setSelected(true);
		else circle.setSelected(true);
		JPanel switchPanel=new JPanel();
		group.add(line);
		group.add(circle);
		switchPanel.add(line);
		switchPanel.add(circle);
		if (guiManager.getState()==2){
			final JFormattedTextField radMin = new JFormattedTextField( NumberFormat.getNumberInstance());
			((NumberFormatter)radMin.getFormatter()).setAllowsInvalid(false);
			radMin.setPreferredSize(new Dimension(35,15));
			final JFormattedTextField radMax = new JFormattedTextField(NumberFormat.getNumberInstance());
			((NumberFormatter)radMax.getFormatter()).setAllowsInvalid(false);
			radMax.setPreferredSize(new Dimension(35,15));
			JButton setRad= new JButton("setzen ");
			setRad.setToolTipText("Radiuswerte setzen");
			setRad.addActionListener(new ActionListener() {
				
				@Override
				public void actionPerformed(ActionEvent e) {
					guiManager.setRadmax(new Integer(radMax.getText().replaceFirst("\\.", "")));	
					guiManager.setRadmin(new Integer(radMin.getText().replaceFirst("\\.", "")));
					if (guiManager.getRadmax()<guiManager.getRadmin()){
						guiManager.setRadmax(guiManager.getRadmin());
					}
					getGuiManager().switchToInteractionSection(0);
					
				}
			});
			radMin.setText(""+guiManager.getRadmin());
			radMax.setText(""+guiManager.getRadmax());
			radMin.setToolTipText("minimaler Radius des Kreises (wird bei Animationen genutzt)");
			radMax.setToolTipText("maximaler Radius des Kreises");
			switchPanel.add(new JLabel("min Radius"));
			switchPanel.add(radMin);
			switchPanel.add(new JLabel("max Radius"));
			switchPanel.add(radMax);
			switchPanel.add(setRad);
		}

		add(switchPanel,BorderLayout.NORTH);
		add(docBrowser);
		
		guiManager.getInteractionSectionSwitch().addInteractionSectionListener(
				new InteractionSectionListener(){

					@Override
					public void sectionSwitched(int from, int to) {

						if(getParent()!=null){
							invalidate();
							getParent().validate();
						}						
		
					}

				});
	}

	private static final long serialVersionUID = 1L;

}
