package gui.sections.interaction;

import gui.GuiManager;
import gui.ImageIconRegistry;
import gui.hough.HoughSpaceAnimation;
import gui.hough.ImagePanel;
import gui.hough.ImagePanelToolbarDecoration;
import gui.hough.ImageSpaceAnimation;
import gui.sections.topic.TopicSection;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.Label;
import java.awt.Panel;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.text.NumberFormat;
import java.util.ArrayList;
import java.util.List;

import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JFormattedTextField;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSlider;

import javax.swing.text.NumberFormatter;

import appLogic.Simulatable;
import appLogic.Simulation;


/**
 * This section is the container for the hough animation.
 * The simulation takes place here.
 */
public class HoughAnimationSection  extends InteractionSection{

	private static final long serialVersionUID = 1297271033714913242L;
	
	private Simulation simulation;

	private ImagePanel imagespace;

	private ImagePanel houghspace;
	
	/**
	 * The Constructor
	 * @param guiManager
	 */
	public HoughAnimationSection(final GuiManager guiManager) {
		super(guiManager);
		setLayout(new BorderLayout());
		
		imagespace = new ImageSpaceAnimation(guiManager.getToolkit().getImagePlus(),getGuiManager().getState(),guiManager.getRadmin(),guiManager.getRadmax());
		houghspace = new HoughSpaceAnimation(guiManager.getToolkit().getImagePlus(),getGuiManager().getState(),guiManager.getRadmin());
		
		
		Panel imagePanel=new Panel(new GridLayout(1,2));
		String workingPath=guiManager.getWorkingPath();
		imagePanel.add(new ImagePanelToolbarDecoration(imagespace,false,workingPath, true));
		imagePanel.add(new ImagePanelToolbarDecoration(houghspace,false,workingPath, false));
		
		Panel controlPanel=new Panel(new GridLayout(1,2));
		
		Panel leftControlPanel=new Panel(new FlowLayout());
		Panel rightControlPanel=new Panel(new BorderLayout());
		
		controlPanel.add(leftControlPanel);
		controlPanel.add(rightControlPanel);
		
			
			
		JButton resetButton;

		resetButton = new JButton("",ImageIconRegistry.getInstance().getIcon("reset"));
		resetButton.setToolTipText("Zurcksetzen");
		resetButton.addActionListener(new ActionListener(){

			@Override
			public void actionPerformed(ActionEvent e) {
				simulation.reset();
				
			}
			
		});
		
		JButton pauseButton=new JButton("",ImageIconRegistry.getInstance().getIcon("pause"));
		pauseButton.setToolTipText("Pause");
		pauseButton.addActionListener(new ActionListener(){

			@Override
			public void actionPerformed(ActionEvent e) {
				simulation.pause();
				
			}
			
		});
		
		JButton stepButton=new JButton("",ImageIconRegistry.getInstance().getIcon("step"));
		stepButton.setToolTipText("Schritt vorwrts");
		stepButton.addActionListener(new ActionListener(){

			@Override
			public void actionPerformed(ActionEvent e) {
				simulation.step();
				
			}
			
		});	
		
		JButton playButton=new JButton("",ImageIconRegistry.getInstance().getIcon("play"));
		playButton.setToolTipText("Abspielen");
		playButton.addActionListener(new ActionListener(){

			@Override
			public void actionPerformed(ActionEvent e) {
				simulation.play();
				
			}
			
		});
		
		JSlider speedSlider=new JSlider(JSlider.HORIZONTAL);
		speedSlider.setMinimum(0);
		speedSlider.setMaximum(1000);
		speedSlider.setValue(30);
		speedSlider.addMouseListener(new MouseAdapter(){

			@Override
			public void mouseReleased(MouseEvent e) {
				super.mouseReleased(e);
				JSlider slider=(JSlider)e.getSource();
				simulation.configure( slider.getValue()/10.0);
			}
			
		});

		
		leftControlPanel.add(resetButton);
		leftControlPanel.add(pauseButton);
		leftControlPanel.add(stepButton);
		
		leftControlPanel.add(playButton);
		rightControlPanel.add(new Label("Geschwindigkeit"),BorderLayout.WEST);
		rightControlPanel.add(speedSlider,BorderLayout.CENTER);
		
		//switchpanel to choose between line and circle
		ButtonGroup group = new ButtonGroup();
		JRadioButton line=new JRadioButton("Geradenerkennung");
		
		line.addActionListener(new ActionListener(){

			@Override
			public void actionPerformed(ActionEvent e) {		
				guiManager.setState(1);	
				((TopicSection)getGuiManager().getsTopic()).changeText(1);
				getGuiManager().switchToInteractionSection(4);
			}	
		});
		JRadioButton circle=new JRadioButton("Kreiserkennung");
		circle.addActionListener(new ActionListener(){

			@Override
			public void actionPerformed(ActionEvent e) {		
				guiManager.setState(2);	
				((TopicSection)getGuiManager().getsTopic()).changeText(2);
				getGuiManager().switchToInteractionSection(4);
			}	
		});
		if (guiManager.getState()==1)line.setSelected(true);
		else circle.setSelected(true);
		JPanel switchPanel=new JPanel();
		group.add(line);
		group.add(circle);
		switchPanel.add(line);
		switchPanel.add(circle);
		if (guiManager.getState()==2){
			final JFormattedTextField radMin = new JFormattedTextField( NumberFormat.getNumberInstance());
			((NumberFormatter)radMin.getFormatter()).setAllowsInvalid(false);
			radMin.setPreferredSize(new Dimension(35,15));
			final JFormattedTextField radMax = new JFormattedTextField(NumberFormat.getNumberInstance());
			((NumberFormatter)radMax.getFormatter()).setAllowsInvalid(false);
			radMax.setPreferredSize(new Dimension(35,15));
			JButton setRad= new JButton("setzen ");
			setRad.setToolTipText("Radiuswerte setzen");
			setRad.addActionListener(new ActionListener() {
				
				@Override
				public void actionPerformed(ActionEvent e) {
					guiManager.setRadmax(new Integer(radMax.getText().replaceFirst("\\.", "")));	
					guiManager.setRadmin(new Integer(radMin.getText().replaceFirst("\\.", "")));
					if (guiManager.getRadmax()<guiManager.getRadmin()){
						guiManager.setRadmax(guiManager.getRadmin());
					}
					getGuiManager().switchToInteractionSection(4);
					
				}
			});
			radMin.setText(""+guiManager.getRadmin());
			radMax.setText(""+guiManager.getRadmax());
			radMin.setToolTipText("minimaler Radius des Kreises (wird bei Animationen genutzt)");
			radMax.setToolTipText("maximaler Radius des Kreises");
			switchPanel.add(new JLabel("min Radius"));
			switchPanel.add(radMin);
			switchPanel.add(new JLabel("max Radius"));
			switchPanel.add(radMax);
			switchPanel.add(setRad);
		}

		add(switchPanel,BorderLayout.NORTH);
		add(imagePanel,BorderLayout.CENTER);
		add(controlPanel,BorderLayout.SOUTH);
		
		
		List<Simulatable> simulatables=new ArrayList<Simulatable>();
		simulatables.add((Simulatable)imagespace);
		simulatables.add((Simulatable)houghspace);
		simulation=new Simulation(simulatables);
		simulation.configure(speedSlider.getValue()/10.0);
	}
}
