package gui.sections.interaction;

import gui.GuiManager;
import gui.hough.HoughCirclePopup;
import gui.hough.HoughSpaceMaxima;
import gui.hough.ImagePanel;
import gui.hough.ImagePanelToolbarDecoration;
import gui.hough.ImageSpaceMaximaLines;
import gui.hough.ImageSpaceMaximaCircles;

import gui.sections.topic.TopicSection;

import java.awt.BorderLayout;
import java.awt.Checkbox;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.Panel;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.awt.event.MouseWheelEvent;
import java.awt.event.MouseWheelListener;
import java.text.NumberFormat;

import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JFormattedTextField;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSlider;

import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.text.NumberFormatter;

/**
 * This Class contains the Section for the "Hough Linien"-topic.
 */
public class HoughSpaceMaximaSection extends InteractionSection{

	private static final long serialVersionUID = 4430016275124207676L;


	private JSlider thresholdSlider;
	private JSlider radiusSlider;
	
	private Checkbox nonMaximumSuppression;


	private ImagePanel imagespace;


	private ImagePanel houghspace;


	private JLabel thresholdLabel;
	
	/**
	 * The constructor
	 * @param guiManager
	 */
	public HoughSpaceMaximaSection(final GuiManager guiManager) {
		super(guiManager);
		setLayout(new BorderLayout());
		
		if(guiManager.getState()==1)imagespace = new ImageSpaceMaximaLines(guiManager.getToolkit().getImagePlus());
		else imagespace = new ImageSpaceMaximaCircles(guiManager.getToolkit().getImagePlus(),guiManager.getRadmin(),guiManager.getRadmax(),guiManager.getRadmin());
		houghspace = new HoughSpaceMaxima(guiManager.getToolkit().getImagePlus(),getGuiManager().getState(),guiManager.getRadmin(),guiManager.getRadmax(),guiManager.getRadmin());
		
		houghspace.addMouseMotionListener((MouseMotionListener) imagespace);
		imagespace.addMouseMotionListener((MouseMotionListener) houghspace);
		if(guiManager.getState()==2){
			houghspace.addMouseListener(new MouseListener() {
				
				@Override
				public void mouseReleased(MouseEvent e) {
					// TODO Auto-generated method stub
					
				}
				
				@Override
				public void mousePressed(MouseEvent e) {
					// TODO Auto-generated method stub
					
				}
				
				@Override
				public void mouseExited(MouseEvent e) {
					// TODO Auto-generated method stub
					
				}
				
				@Override
				public void mouseEntered(MouseEvent e) {
					// TODO Auto-generated method stub
					
				}
				
				@Override
				public void mouseClicked(MouseEvent e) {
					HoughCirclePopup popup = new HoughCirclePopup(((HoughSpaceMaxima)houghspace).getMaxima());
					if(popup.isVisible()==true)popup.setVisible(false);
					else popup.setVisible(true);
				}
			});
		}
		
		Panel imagePanel=new Panel(new GridLayout(1,2));
		imagePanel.add(new ImagePanelToolbarDecoration(imagespace,false,guiManager.getWorkingPath(), true));
		imagePanel.add(new ImagePanelToolbarDecoration(houghspace,false,guiManager.getWorkingPath(), false));
		
		Panel controlPanel=new Panel(new GridLayout(1,2));
		
		Panel leftControlPanel=new Panel(new FlowLayout());
		Panel rightControlPanel=new Panel(new BorderLayout());
		
		controlPanel.add(leftControlPanel);
		controlPanel.add(rightControlPanel);
		
		if(guiManager.getState()==1){
			nonMaximumSuppression=new Checkbox("Non Maximum Unterdrckung");
			nonMaximumSuppression.addItemListener(new ItemListener(){

				@Override
				public void itemStateChanged(ItemEvent e) {
					if(guiManager.getState()==1){
						((ImageSpaceMaximaLines) imagespace).updateThreshold(thresholdSlider.getValue()/255.0,nonMaximumSuppression.getState(),null);
					}
					else ((ImageSpaceMaximaCircles)imagespace)
					.updateThreshold(thresholdSlider.getValue()/255.0,null,radiusSlider.getValue());
					((HoughSpaceMaxima)houghspace)
						.updateThreshold(thresholdSlider.getValue()/255.0,nonMaximumSuppression.getState(),0);					
				}
			});
			
			leftControlPanel.add(nonMaximumSuppression);
		}
		else{
			leftControlPanel.setLayout(new BorderLayout());
			radiusSlider=new JSlider(JSlider.HORIZONTAL);
			radiusSlider.setMinimum(guiManager.getRadmin());
			radiusSlider.setMaximum(guiManager.getRadmax());
			radiusSlider.setMajorTickSpacing((Integer)((guiManager.getRadmax()-guiManager.getRadmin()+1)/5));
			radiusSlider.setMinorTickSpacing((Integer)((guiManager.getRadmax()-guiManager.getRadmin()+1)/10));
			radiusSlider.setPaintTicks(true);
			radiusSlider.setPaintLabels(true);
			radiusSlider.addMouseListener(new MouseAdapter(){

				@Override
				public void mouseReleased(MouseEvent e) {
					super.mouseReleased(e);
					((ImageSpaceMaximaCircles)imagespace).updateThreshold(thresholdSlider.getValue()/255.0,null,radiusSlider.getValue());
					((HoughSpaceMaxima)houghspace)
						.updateThreshold(thresholdSlider.getValue()/255.0,false,radiusSlider.getValue());
				}
				
			});
			final JLabel radiusLabel=new JLabel("Radius: "+guiManager.getRadmin());
			radiusSlider.addChangeListener(new ChangeListener() {
				
				@Override
				public void stateChanged(ChangeEvent e) {
					JSlider s=((JSlider)e.getSource());
					radiusLabel.setText("Radius: "+s.getValue());
					
				}
			});
			radiusSlider.addMouseWheelListener(new MouseWheelListener() {
				
				@Override
				public void mouseWheelMoved(MouseWheelEvent e) {
					if( e.getWheelRotation()<0){
						radiusSlider.setValue(radiusSlider.getValue()+1);
						
					}
					else{
						radiusSlider.setValue(radiusSlider.getValue()-1);
					}
					((ImageSpaceMaximaCircles)imagespace).updateThreshold(thresholdSlider.getValue()/255.0,null,radiusSlider.getValue());
					((HoughSpaceMaxima)houghspace)
						.updateThreshold(thresholdSlider.getValue()/255.0,false,radiusSlider.getValue());
					
				}
			});
		
			radiusSlider.setValue(guiManager.getRadmin());
			
			
			leftControlPanel.add(radiusLabel,BorderLayout.WEST);
			leftControlPanel.add(radiusSlider,BorderLayout.CENTER);
		}

		thresholdSlider=new JSlider(JSlider.HORIZONTAL);
		thresholdSlider.setMinimum(0);
		thresholdSlider.setMaximum(255);
		thresholdSlider.setMajorTickSpacing(50);
		thresholdSlider.setMinorTickSpacing(10);
		thresholdSlider.setPaintTicks(true);
		thresholdSlider.setPaintLabels(true);
		thresholdSlider.addMouseListener(new MouseAdapter(){

			@Override
			public void mouseReleased(MouseEvent e) {
				super.mouseReleased(e);
				if(guiManager.getState()==1){
					((ImageSpaceMaximaLines)imagespace).updateThreshold(thresholdSlider.getValue()/255.0,nonMaximumSuppression.getState(),null);
					((HoughSpaceMaxima)houghspace).updateThreshold(thresholdSlider.getValue()/255.0,false,0);	
					
				}
				else {
					((ImageSpaceMaximaCircles)imagespace).updateThreshold(thresholdSlider.getValue()/255.0,null,radiusSlider.getValue());
					((HoughSpaceMaxima)houghspace).updateThreshold(thresholdSlider.getValue()/255.0,false,radiusSlider.getValue());	
				}
			}
		});
		if (guiManager.getState()==1){
			thresholdLabel=new JLabel("Schwellwert: 128");
		}
		else{
			thresholdLabel=new JLabel("Schwellwert: 191");
		}
		thresholdSlider.addChangeListener(new ChangeListener() {
			
			@Override
			public void stateChanged(ChangeEvent e) {
				JSlider s=((JSlider)e.getSource());
				thresholdLabel.setText("Schwellwert: "+s.getValue());
				
			}
		});
		if (guiManager.getState()==1){
			thresholdSlider.setValue(128);
		}
		else{
			thresholdSlider.setValue(191);
		}
		
		rightControlPanel.add(thresholdLabel,BorderLayout.WEST);
		rightControlPanel.add(thresholdSlider,BorderLayout.CENTER);
		
		
	
		//switchpanel to choose between line and circle
		ButtonGroup group = new ButtonGroup();
		JRadioButton line=new JRadioButton("Geradenerkennung");
		line.addActionListener(new ActionListener(){

			@Override
			public void actionPerformed(ActionEvent e) {		
				guiManager.setState(1);	
				((TopicSection)getGuiManager().getsTopic()).changeText(1);
				getGuiManager().switchToInteractionSection(5);
			}	
		});
		JRadioButton circle=new JRadioButton("Kreiserkennung");
		circle.addActionListener(new ActionListener(){

			@Override
			public void actionPerformed(ActionEvent e) {		
				guiManager.setState(2);		
				((TopicSection)getGuiManager().getsTopic()).changeText(2);
				getGuiManager().switchToInteractionSection(5);
			}	
		});
		if (guiManager.getState()==1)line.setSelected(true);
		else circle.setSelected(true);
		JPanel switchPanel=new JPanel();
		group.add(line);
		group.add(circle);
		switchPanel.add(line);
		switchPanel.add(circle);
		if (guiManager.getState()==2){
			final JFormattedTextField radMin = new JFormattedTextField( NumberFormat.getNumberInstance());
			((NumberFormatter)radMin.getFormatter()).setAllowsInvalid(false);
			radMin.setPreferredSize(new Dimension(35,15));
			final JFormattedTextField radMax = new JFormattedTextField(NumberFormat.getNumberInstance());
			((NumberFormatter)radMax.getFormatter()).setAllowsInvalid(false);
			radMax.setPreferredSize(new Dimension(35,15));
			JButton setRad= new JButton("setzen ");
			setRad.setToolTipText("Radiuswerte setzen");
			setRad.addActionListener(new ActionListener() {
				
				@Override
				public void actionPerformed(ActionEvent e) {
					guiManager.setRadmax(new Integer(radMax.getText().replaceFirst("\\.", "")));	
					guiManager.setRadmin(new Integer(radMin.getText().replaceFirst("\\.", "")));
					if (guiManager.getRadmax()<guiManager.getRadmin()){
						guiManager.setRadmax(guiManager.getRadmin());
					}
					getGuiManager().switchToInteractionSection(5);
					
				}
			});
			radMin.setText(""+guiManager.getRadmin());
			radMax.setText(""+guiManager.getRadmax());
			radMin.setToolTipText("minimaler Radius des Kreises (wird bei Animationen genutzt)");
			radMax.setToolTipText("maximaler Radius des Kreises");
			switchPanel.add(new JLabel("min Radius"));
			switchPanel.add(radMin);
			switchPanel.add(new JLabel("max Radius"));
			switchPanel.add(radMax);
			switchPanel.add(setRad);
		}

		add(switchPanel,BorderLayout.NORTH);
		add(imagePanel,BorderLayout.CENTER);
		add(controlPanel,BorderLayout.SOUTH);
			}

}
