package gui.sections.interaction;

import gui.GuiManager;
import gui.hough.HoughSpaceImageEdit;

import gui.hough.ImagePanel;
import gui.hough.ImagePanelToolbarDecoration;
import gui.hough.ImageSpaceWithCircles;
import gui.hough.ImageSpaceWithLines;
import gui.sections.topic.TopicSection;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.Panel;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import java.awt.event.MouseMotionListener;
import java.text.NumberFormat;

import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JFormattedTextField;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;

import javax.swing.text.NumberFormatter;


/**
 * This Class contains the section for the "Bild bearbeiten"-topic
 */
public class ImageEditSection extends InteractionSection {

	private static final long serialVersionUID = -3868591206010372392L;

	private Panel imagePanel;

	private ImagePanel imagespace;

	private ImagePanel houghspace;

	/**
	 * The constructor
	 * 
	 * @param guiManager
	 */
	public ImageEditSection(final GuiManager guiManager) {
		super(guiManager);
		setLayout(new BorderLayout());
		
		if(guiManager.getState()==1)imagespace = new ImageSpaceWithLines(guiManager.getToolkit().getImagePlus());
		else imagespace = new ImageSpaceWithCircles(guiManager.getToolkit().getImagePlus(),guiManager.getRadmin(),guiManager.getRadmax(),guiManager.getRadmin());
		houghspace = new HoughSpaceImageEdit(guiManager.getToolkit().getImagePlus(),getGuiManager().getState(),guiManager.getRadmin());

		imagespace.addMouseMotionListener((MouseMotionListener) houghspace);
		houghspace.addMouseMotionListener((MouseMotionListener) imagespace);

		imagePanel = new Panel(new GridLayout(1, 2));
		imagePanel.add(new ImagePanelToolbarDecoration(imagespace, true,
				guiManager.getWorkingPath(), true));

		imagePanel.add(new ImagePanelToolbarDecoration(houghspace, false,
				guiManager.getWorkingPath(), false));

		
		//switchpanel to choose between line and circle
				ButtonGroup group = new ButtonGroup();
				JRadioButton line=new JRadioButton("Geradenerkennung");
				line.addActionListener(new ActionListener(){

					@Override
					public void actionPerformed(ActionEvent e) {		
						guiManager.setState(1);	
						((TopicSection)getGuiManager().getsTopic()).changeText(1);
						getGuiManager().switchToInteractionSection(3);
					}	
				});
				JRadioButton circle=new JRadioButton("Kreiserkennung");
				circle.addActionListener(new ActionListener(){
					@Override
					public void actionPerformed(ActionEvent e) {		
						guiManager.setState(2);	
						
						((TopicSection)getGuiManager().getsTopic()).changeText(2);
						getGuiManager().switchToInteractionSection(3);
						
					}
				
				});
				if (guiManager.getState()==1)line.setSelected(true);
				else circle.setSelected(true);
				
				JPanel switchPanel=new JPanel();
				group.add(line);
				group.add(circle);
				switchPanel.add(line);
				switchPanel.add(circle);
				if (guiManager.getState()==2){
					final JFormattedTextField radMin = new JFormattedTextField( NumberFormat.getNumberInstance());
					((NumberFormatter)radMin.getFormatter()).setAllowsInvalid(false);
					radMin.setPreferredSize(new Dimension(35,15));
					final JFormattedTextField radMax = new JFormattedTextField(NumberFormat.getNumberInstance());
					((NumberFormatter)radMax.getFormatter()).setAllowsInvalid(false);
					radMax.setPreferredSize(new Dimension(35,15));
					JButton setRad= new JButton("setzen ");
					setRad.setToolTipText("Radiuswerte setzen");
					setRad.addActionListener(new ActionListener() {
						
						@Override
						public void actionPerformed(ActionEvent e) {
							guiManager.setRadmax(new Integer(radMax.getText().replaceFirst("\\.", "")));	
							guiManager.setRadmin(new Integer(radMin.getText().replaceFirst("\\.", "")));
							if (guiManager.getRadmax()<guiManager.getRadmin()){
								guiManager.setRadmax(guiManager.getRadmin());
							}
							getGuiManager().switchToInteractionSection(3);
							
						}
					});
					radMin.setText(""+guiManager.getRadmin());
					radMax.setText(""+guiManager.getRadmax());
					radMin.setToolTipText("minimaler Radius des Kreises (wird bei Animationen genutzt)");
					radMax.setToolTipText("maximaler Radius des Kreises");
					switchPanel.add(new JLabel("min Radius"));
					switchPanel.add(radMin);
					switchPanel.add(new JLabel("max Radius"));
					switchPanel.add(radMax);
					switchPanel.add(setRad);
				}
				
				add(switchPanel,BorderLayout.NORTH);

		add(imagePanel, BorderLayout.CENTER);

	}

}
